@@ -18,8 +18,8 @@ from linodecli.exit_codes import ExitCodes
 from linodecli.helpers import API_CA_PATH, API_VERSION_OVERRIDE
 
 from .baked.operation import (
-    ExplicitEmptyDictValue,
     ExplicitEmptyListValue,
+    ExplicitJsonValue,
     ExplicitNullValue,
     OpenAPIOperation,
 )
@@ -314,14 +314,14 @@ def _traverse_request_body(o: Any) -> Any:
                 result[k] = []
                 continue
 
-            if isinstance(v, ExplicitEmptyDictValue):
-                result[k] = {}
-                continue
-
             if isinstance(v, ExplicitNullValue):
                 result[k] = None
                 continue
 
+            if isinstance(v, ExplicitJsonValue):
+                result[k] = v.json_value
+                continue
+
             value = _traverse_request_body(v)
 
             # We should exclude implicit empty lists
